#[repr(u8)]pub enum Updhld {
UPDHLD_0 = 0,
UPDHLD_1 = 1,
}Variants
UPDHLD_0 = 0
Disable updates of hold registers on the rising edge of TRIGGER input signal
UPDHLD_1 = 1
Enable updates of hold registers on the rising edge of TRIGGER input signal
Implementations